| /freebsd-12.1/contrib/libstdc++/libmath/ |
| H A D | mathconf.h | 73 typedef unsigned int U_int32_t __attribute ((mode (SI))); typedef 74 typedef int Int32_t __attribute ((mode (SI))); typedef 75 typedef unsigned int U_int64_t __attribute ((mode (DI))); typedef 76 typedef int Int64_t __attribute ((mode (DI))); typedef
|
| /freebsd-12.1/contrib/libgnuregex/ |
| H A D | regex_internal.h | 126 # define __attribute(arg) __attribute__ (arg) macro 128 # define __attribute(arg) macro 382 # define internal_function __attribute ((regparm (3), stdcall)) 401 internal_function __attribute ((pure)); 719 internal_function __attribute ((pure)) in internal_function() 732 internal_function __attribute ((pure)) in internal_function() 742 internal_function __attribute ((pure)) in internal_function()
|
| H A D | regex_internal.c | 834 internal_function __attribute ((pure)) in internal_function() 1356 internal_function __attribute ((pure)) in internal_function() 1371 internal_function __attribute ((pure)) in internal_function()
|
| H A D | regcomp.c | 289 __attribute ((always_inline)) in weak_alias() 2783 __attribute ((always_inline)) in parse_bracket_exp() 2809 __attribute ((always_inline)) in parse_bracket_exp() 2877 __attribute ((always_inline)) in parse_bracket_exp() 2957 __attribute ((always_inline)) in parse_bracket_exp()
|
| H A D | regexec.c | 1051 __attribute ((always_inline)) internal_function
|
| /freebsd-12.1/contrib/libpcap/pcap/ |
| H A D | funcattrs.h | 172 #define PCAP_NORETURN __attribute((noreturn)) 173 #define PCAP_NORETURN_DEF __attribute((noreturn))
|
| /freebsd-12.1/contrib/gcclibs/libmudflap/ |
| H A D | mf-runtime.h | 89 __attribute((nothrow)); 91 __attribute((nothrow)); 93 __attribute((nothrow));
|
| /freebsd-12.1/contrib/llvm/tools/clang/lib/Headers/ |
| H A D | __clang_cuda_runtime_wrapper.h | 355 __device__ void free(void *) __attribute((nothrow)); 356 __device__ void *malloc(size_t) __attribute((nothrow)) __attribute__((malloc));
|
| /freebsd-12.1/contrib/tcpdump/ |
| H A D | funcattrs.h | 78 #define NORETURN __attribute((noreturn))
|
| H A D | configure | 3648 main(int argc __attribute((unused)), char **argv __attribute((unused)))
|
| /freebsd-12.1/contrib/compiler-rt/lib/profile/ |
| H A D | InstrProfilingPort.h | 32 #define COMPILER_RT_ALWAYS_INLINE inline __attribute((always_inline))
|
| /freebsd-12.1/sbin/routed/rtquery/ |
| H A D | rtquery.c | 129 static void trace_loop(char *argv[]) __attribute((__noreturn__)); 130 static void query_loop(char *argv[], int) __attribute((__noreturn__));
|
| /freebsd-12.1/sys/contrib/octeon-sdk/ |
| H A D | cvmx-debug.c | 115 static char cvmx_debug_stack[8*1024] __attribute ((aligned (16))); 133 static char cvmx_debug_stack_all[CVMX_MAX_CORES][8*1024] __attribute ((aligned (16)));
|
| /freebsd-12.1/contrib/llvm/include/llvm/ADT/ |
| H A D | StringRef.h | 880 __attribute((enable_if(__builtin_strlen(Str) == N - 1, in StringLiteral()
|
| /freebsd-12.1/contrib/llvm/tools/clang/include/clang/Basic/ |
| H A D | TokenKinds.def | 400 KEYWORD(__attribute , KEYALL) 594 ALIAS("__attribute__", __attribute, KEYALL)
|
| /freebsd-12.1/crypto/openssl/crypto/ec/ |
| H A D | ecp_nistz256.c | 35 # define ALIGN32 __attribute((aligned(32)))
|
| H A D | ecp_nistz256_table.c | 25 __attribute((aligned(4096)))
|
| /freebsd-12.1/contrib/xz/ |
| H A D | ChangeLog | 4563 Add underscores to attributes (__attribute((__foo__))).
|
| /freebsd-12.1/contrib/gcc/cp/ |
| H A D | ChangeLog | 1614 (cp_parser_type_specifier): Allow 'enum __attribute ((...)) E'.
|
| /freebsd-12.1/contrib/gcc/doc/ |
| H A D | extend.texi | 11138 A using-directive with @code{__attribute ((strong))} is stronger 11163 using namespace debug __attribute ((__strong__));
|
| H A D | tm.texi | 8785 @code{__declspec(X)} as equivalent to @code{__attribute((X))}. By
|
| H A D | invoke.texi | 13638 effective to use @samp{__attribute ((visibility))} and/or
|
| /freebsd-12.1/contrib/ntp/ |
| H A D | CommitLog | 128339 mark isc_assertioncallback_t __attribute((__noreturn__)) 128342 add __attribute((__noreturn__)) to __attribute__ compat header snippet. 128348 Mark isc_assertioncallback_t __attribute((__noreturn__))
|